==> qt-creator-opensource-src-3.4.1.zip: qt-creator-opensource-src-3.4.1/src/plugins/qmakeprojectmanager/qmakekitconfigwidget.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMAKEKITCONFIGWIDGET_H
#define QMAKEKITCONFIGWIDGET_H

#include <projectexplorer/kitconfigwidget.h>

QT_BEGIN_NAMESPACE
class QLineEdit;
QT_END_NAMESPACE

namespace QmakeProjectManager {
namespace Internal {

class QmakeKitConfigWidget : public ProjectExplorer::KitConfigWidget
{
    Q_OBJECT

public:
    QmakeKitConfigWidget(ProjectExplorer::Kit *k, const ProjectExplorer::KitInformation *ki);
    ~QmakeKitConfigWidget();

    QWidget *mainWidget() const;
    QString displayName() const;
    QString toolTip() const;

    void makeReadOnly();
    void refresh();

private slots:
    void mkspecWasChanged(const QString &text);

private:
    int findQtVersion(const int id) const;

    QLineEdit *m_lineEdit;
    bool m_ignoreChange;
};

} // namespace Internal
} // namespace QmakeProjectManager

#endif // QMAKEKITCONFIGWIDGET_H

==> qt-creator-opensource-src-3.6.0.zip: qt-creator-opensource-src-3.6.0/src/plugins/qmakeprojectmanager/qmakekitconfigwidget.h <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company.  For licensing terms and
** conditions see http://www.qt.io/terms-conditions.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, The Qt Company gives you certain additional
** rights.  These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMAKEKITCONFIGWIDGET_H
#define QMAKEKITCONFIGWIDGET_H

#include <projectexplorer/kitconfigwidget.h>

QT_BEGIN_NAMESPACE
class QLineEdit;
QT_END_NAMESPACE

namespace QmakeProjectManager {
namespace Internal {

class QmakeKitConfigWidget : public ProjectExplorer::KitConfigWidget
{
    Q_OBJECT

public:
    QmakeKitConfigWidget(ProjectExplorer::Kit *k, const ProjectExplorer::KitInformation *ki);
    ~QmakeKitConfigWidget();

    QWidget *mainWidget() const;
    QString displayName() const;
    QString toolTip() const;

    void makeReadOnly();
    void refresh();

private slots:
    void mkspecWasChanged(const QString &text);

private:
    int findQtVersion(const int id) const;

    QLineEdit *m_lineEdit = nullptr;
    bool m_ignoreChange = false;
};

} // namespace Internal
} // namespace QmakeProjectManager

#endif // QMAKEKITCONFIGWIDGET_H
